==> use-spotify-web-playback-sdk-0.0.8-0.tgz: package/dist-src/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React from "react";
import { Script as _Script } from "the-platform";

var noop = function noop() {};

export function useSpotifyWebSdk(_ref) {
  var name = _ref.name,
      _getOAuthToken = _ref.getOAuthToken,
      _ref$onAccountError = _ref.onAccountError,
      onAccountError = _ref$onAccountError === void 0 ? noop : _ref$onAccountError,
      _ref$onNotReady = _ref.onNotReady,
      onNotReady = _ref$onNotReady === void 0 ? noop : _ref$onNotReady,
      _ref$onInitializeErro = _ref.onInitializeError,
      onInitializeError = _ref$onInitializeErro === void 0 ? noop : _ref$onInitializeErro,
      _ref$onAuthError = _ref.onAuthError,
      onAuthError = _ref$onAuthError === void 0 ? noop : _ref$onAuthError,
      _ref$onReady = _ref.onReady,
      onReady = _ref$onReady === void 0 ? noop : _ref$onReady,
      _ref$onPlayerStateCha = _ref.onPlayerStateChanged,
      onPlayerStateChanged = _ref$onPlayerStateCha === void 0 ? noop : _ref$onPlayerStateCha;

  var _React$useState = React.useState(false),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      isReady = _React$useState2[0],
      setIsReady = _React$useState2[1];

  var _React$useState3 = React.useState(null),
      _React$useState4 = _slicedToArray(_React$useState3, 2),
      deviceId = _React$useState4[0],
      setDeviceId = _React$useState4[1];

  var playerRef = React.useRef(null);
  React.useEffect(function () {
    window.onSpotifyWebPlaybackSDKReady = function () {
      playerRef.current = new Spotify.Player({
        name: name,
        getOAuthToken: function () {
          var _getOAuthToken2 = _asyncToGenerator(
          /*#__PURE__*/
          regeneratorRuntime.mark(function _callee(cb) {
            var token;
            return regeneratorRuntime.wrap(function _callee$(_context) {
              while (1) {
                switch (_context.prev = _context.next) {
                  case 0:
                    _context.next = 2;
                    return _getOAuthToken();

                  case 2:
                    token = _context.sent;
                    cb(token);

                  case 4:
                  case "end":
                    return _context.stop();
                }
              }
            }, _callee);
          }));

          function getOAuthToken(_x) {
            return _getOAuthToken2.apply(this, arguments);
          }

          return getOAuthToken;
        }()
      });
      setIsReady(true);
    };
  }, []);
  var handleReady = React.useCallback(function (_ref2) {
    var readyDeviceId = _ref2.device_id;
    setDeviceId(readyDeviceId);

    if (onReady) {
      onReady(deviceId);
    }
  }, []);
  var handleAccountError = React.useCallback(onAccountError, []);
  var handleInitializationError = React.useCallback(onInitializeError, []);
  var handleAuthError = React.useCallback(onAuthError, []);
  var handleNotReady = React.useCallback(onNotReady, []);
  var handlePlayerStateChange = React.useCallback(onPlayerStateChanged, []);
  var connect = React.useCallback(function () {
    player.connect();
  }, []);
  React.useEffect(function () {
    var player = playerRef.current;

    if (isReady) {
      player.addListener("account_error", handleAccountError);
      player.addListener("ready", handleReady);
      player.addListener("initialization_error", handleInitializationError);
      player.addListener("authentication_error", handleAuthError);
      player.addListener("not_ready", handleNotReady);
      player.addListener("player_state_changed", handlePlayerStateChange);
      return function () {
        player.removeEventListener("ready", handleReady);
        player.removeEventListener("initialization_error", handleInitializationError);
        player.removeEventListener("authentication_error", handleAuthError);
        player.removeEventListener("not_ready", handleNotReady);
        player.removeEventListener("player_state_changed", handlePlayerStateChange);
      };
    }

    return;
  }, [isReady]);
  return {
    isReady: isReady,
    deviceId: deviceId,
    connect: connect,
    player: playerRef.current,
    Script: function Script(props) {
      return React.createElement(_Script, _extends({
        src: "https://sdk.scdn.co/spotify-player.js"
      }, props));
    }
  };
}
export default useSpotifyWebSdk;

==> use-spotify-web-playback-sdk-0.0.10-0.tgz: package/dist-src/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React from 'react';
import { Script as _Script } from 'the-platform';

var noop = function noop() {};

export function useSpotifyWebSdk(_ref) {
  var name = _ref.name,
      _getOAuthToken = _ref.getOAuthToken,
      _ref$onAccountError = _ref.onAccountError,
      onAccountError = _ref$onAccountError === void 0 ? noop : _ref$onAccountError,
      _ref$onNotReady = _ref.onNotReady,
      onNotReady = _ref$onNotReady === void 0 ? noop : _ref$onNotReady,
      _ref$onInitializeErro = _ref.onInitializeError,
      onInitializeError = _ref$onInitializeErro === void 0 ? noop : _ref$onInitializeErro,
      _ref$onAuthError = _ref.onAuthError,
      onAuthError = _ref$onAuthError === void 0 ? noop : _ref$onAuthError,
      _ref$onReady = _ref.onReady,
      onReady = _ref$onReady === void 0 ? noop : _ref$onReady,
      _ref$onPlayerStateCha = _ref.onPlayerStateChanged,
      onPlayerStateChanged = _ref$onPlayerStateCha === void 0 ? noop : _ref$onPlayerStateCha;

  var _React$useState = React.useState(false),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      isReady = _React$useState2[0],
      setIsReady = _React$useState2[1];

  var _React$useState3 = React.useState(null),
      _React$useState4 = _slicedToArray(_React$useState3, 2),
      deviceId = _React$useState4[0],
      setDeviceId = _React$useState4[1];

  var playerRef = React.useRef(null);
  React.useEffect(function () {
    window.onSpotifyWebPlaybackSDKReady = function () {
      playerRef.current = new Spotify.Player({
        name: name,
        getOAuthToken: function () {
          var _getOAuthToken2 = _asyncToGenerator(
          /*#__PURE__*/
          regeneratorRuntime.mark(function _callee(cb) {
            var token;
            return regeneratorRuntime.wrap(function _callee$(_context) {
              while (1) {
                switch (_context.prev = _context.next) {
                  case 0:
                    _context.next = 2;
                    return _getOAuthToken();

                  case 2:
                    token = _context.sent;
                    cb(token);

                  case 4:
                  case "end":
                    return _context.stop();
                }
              }
            }, _callee);
          }));

          function getOAuthToken(_x) {
            return _getOAuthToken2.apply(this, arguments);
          }

          return getOAuthToken;
        }()
      });
      setIsReady(true);
    };
  }, []);
  var handleReady = React.useCallback(function (_ref2) {
    var readyDeviceId = _ref2.device_id;
    setDeviceId(readyDeviceId);

    if (onReady) {
      onReady(deviceId);
    }
  }, []);
  var handleAccountError = React.useCallback(onAccountError, []);
  var handleInitializationError = React.useCallback(onInitializeError, []);
  var handleAuthError = React.useCallback(onAuthError, []);
  var handleNotReady = React.useCallback(onNotReady, []);
  var handlePlayerStateChange = React.useCallback(onPlayerStateChanged, []);
  var connect = React.useCallback(function () {
    if (playerRef.current) {
      playerRef.current.connect();
      return;
    }

    throw new Error('Player is not initialized');
  }, []);
  React.useEffect(function () {
    var player = playerRef.current;

    if (isReady) {
      player.addListener('account_error', handleAccountError);
      player.addListener('ready', handleReady);
      player.addListener('initialization_error', handleInitializationError);
      player.addListener('authentication_error', handleAuthError);
      player.addListener('not_ready', handleNotReady);
      player.addListener('player_state_changed', handlePlayerStateChange);
      return function () {
        player.removeEventListener('ready', handleReady);
        player.removeEventListener('initialization_error', handleInitializationError);
        player.removeEventListener('authentication_error', handleAuthError);
        player.removeEventListener('not_ready', handleNotReady);
        player.removeEventListener('player_state_changed', handlePlayerStateChange);
      };
    }

    return;
  }, [isReady]);
  return {
    isReady: isReady,
    deviceId: deviceId,
    connect: connect,
    player: playerRef.current,
    Script: function Script(props) {
      return React.createElement(_Script, _extends({
        src: "https://sdk.scdn.co/spotify-player.js"
      }, props));
    }
  };
}
export default useSpotifyWebSdk;
